@@ -1,6 +1,9 @@
 import sys
 import os
 
+if __name__ == "__main__":
+    os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"
+
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 if __name__ == "__main__":
     import argparse
@@ -41,30 +44,44 @@ def fold_batchnormalization_layers(model: Any, verbose: bool) -> Tuple[Any, str]
 
 
 if __name__ == "__main__":
+    from UnitTest.test_a_model import test_model_changes
+
     mod = tf.keras.applications.resnet50.ResNet50(weights=None)
     mod._name = "ResNet_50"
     folded_model, output_str = fold_batchnormalization_layers(mod, True)
+    test_model_changes(model=mod, folded_model=folded_model)
     mod = tf.keras.applications.efficientnet.EfficientNetB0(weights=None)
     mod._name = "EfficientNet_B0"
     folded_model, output_str = fold_batchnormalization_layers(mod, True)
+    test_model_changes(model=mod, folded_model=folded_model)
     mod = tf.keras.applications.mobilenet_v2.MobileNetV2(weights=None)
     mod._name = "MobileNet_V2"
     folded_model, output_str = fold_batchnormalization_layers(mod, True)
+    test_model_changes(model=mod, folded_model=folded_model)
     mod = tf.keras.applications.MobileNetV3Small(weights=None)
     mod._name = "MobileNet_V3"
     folded_model, output_str = fold_batchnormalization_layers(mod, True)
+    test_model_changes(model=mod, folded_model=folded_model)
     mod = tf.keras.applications.inception_resnet_v2.InceptionResNetV2(weights=None)
     mod._name = "Inception_ResNet_V2"
     folded_model, output_str = fold_batchnormalization_layers(mod, True)
+    test_model_changes(
+        model=mod, folded_model=folded_model, input_shape=(1, 299, 299, 3)
+    )
     mod = tf.keras.applications.inception_v3.InceptionV3(weights=None)
     mod._name = "Inception_V3"
     folded_model, output_str = fold_batchnormalization_layers(mod, True)
+    test_model_changes(
+        model=mod, folded_model=folded_model, input_shape=(1, 299, 299, 3)
+    )
     mod = tf.keras.applications.nasnet.NASNetMobile(weights=None)
     mod._name = "NASNet"
     folded_model, output_str = fold_batchnormalization_layers(mod, True)
+    test_model_changes(model=mod, folded_model=folded_model)
     mod = tf.keras.applications.densenet.DenseNet121(weights=None)
     mod._name = "DenseNet_121"
     folded_model, output_str = fold_batchnormalization_layers(mod, True)
+    test_model_changes(model=mod, folded_model=folded_model)
     print("+--------------------------------+")
     print(f"|            Summary             |")
     print("+--------------------------------+")
